import unittest

import easyglue

from pyspark.context import SparkContext
from awsglue.context import GlueContext


class TestReadOthers(unittest.TestCase):

    glue = GlueContext(SparkContext.getOrCreate())

    def test_dynamodb(self):
        data = self.glue.read().dynamodb("easyglue")
        self.assertEqual(4, data.count())

    def test_ddb(self):
        data = self.glue.read().ddb("easyglue")
        self.assertEqual(4, data.count())


if __name__ == '__main__':
    unittest.main()



from typing import Any
import re

from awsglue.context import GlueContext
from awsglue.dynamicframe import DynamicFrame

from easyglue.utils import reader_method

QUALIFIED_NAME_MATCH_REGEX = "[a-zA-Z0-9_]+\\.[a-zA-Z0-9_]+"
QUALIFIED_NAME_MATCH_CAPTURE = "[a-zA-Z0-9_]+"


def _validate_qualified_name(qualified_name: str) -> tuple:
    """
    Validates that the provided qualified name is in the form of "database.table" and if so, returns each part
    :param qualified_name: Qualified name of the table
    :return: Database name, table name
    """
    if not re.match(QUALIFIED_NAME_MATCH_REGEX, qualified_name):
        raise ValueError('Provided table name is not in the form of "database.table"')
    else:
        matches = re.findall(QUALIFIED_NAME_MATCH_CAPTURE, qualified_name)
        return matches[0], matches[1]


class CatalogMixin:
    glue_context: GlueContext
    additional_options_dict: dict

    @reader_method
    def catalog(self, database_name: str, table_name: str, redshift_tmp_dir: str = "", transformation_ctx: str = "",
                push_down_predicate: str = "", catalog_id: int = None, **kwargs: Any) -> DynamicFrame:
        """
        Reads a dataset from Catalog by calling create_dynamic_frame.from_catalog with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param database_name: Name of the Data Catalog database containing the table
        :param table_name: Name of the Data Catalog table
        :param redshift_tmp_dir: Temporary path to be used when reading/writing from/to Redshift
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param catalog_id: Data Catalog ID containing the referenced database and table names
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the Data Catalog table
        """
        return self.glue_context.create_dynamic_frame_from_catalog(database=database_name,
                                                                   table_name=table_name,
                                                                   redshift_tmp_dir=redshift_tmp_dir,
                                                                   transformation_ctx=transformation_ctx,
                                                                   push_down_predicate=push_down_predicate,
                                                                   additional_options=self.additional_options_dict,
                                                                   catalog_id=catalog_id,
                                                                   kwargs=kwargs)

    @reader_method
    def table(self, qualified_name: str, redshift_tmp_dir: str = "", transformation_ctx: str = "",
              push_down_predicate: str = "", catalog_id: int = None, **kwargs: Any) -> DynamicFrame:
        """
        Reads a dataset from a Data Catalog qualified table name with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param qualified_name: Qualified name (database.table) of the table to read from
        :param redshift_tmp_dir: Temporary path to be used when reading/writing from/to Redshift
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param catalog_id: Data Catalog ID containing the referenced database and table names
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the Data Catalog table
        """
        database_name, table_name = _validate_qualified_name(qualified_name)
        return self.glue_context.create_dynamic_frame_from_catalog(database=database_name,
                                                                   table_name=table_name,
                                                                   redshift_tmp_dir=redshift_tmp_dir,
                                                                   transformation_ctx=transformation_ctx,
                                                                   push_down_predicate=push_down_predicate,
                                                                   additional_options=self.additional_options_dict,
                                                                   catalog_id=catalog_id,
                                                                   kwargs=kwargs)



import unittest

import easyglue

from pyspark.context import SparkContext
from awsglue.context import GlueContext


class TestEasyDynamicFrameReader(unittest.TestCase):
    glue = GlueContext(SparkContext.getOrCreate())

    def test_format_option(self):
        data = self.glue.read().format_option("withHeader", True).csv("s3://bertolb/sampledata/mockaroo/csv/")
        self.assertEqual(1000, data.count())

    def test_format_options(self):
        data = self.glue.read().format_options({"withHeader": True}).csv("s3://bertolb/sampledata/mockaroo/csv/")
        self.assertEqual(1000, data.count())

    def test_connection_option(self):
        data = self.glue.read().connection_option("compression", "gzip")\
            .json("s3://bertolb/sampledata/mockaroo/json-gzip/")
        self.assertEqual(1000, data.count())

    def test_connection_options(self):
        data = self.glue.read().connection_options({"compression": "gzip"})\
            .json("s3://bertolb/sampledata/mockaroo/json-gzip/")
        self.assertEqual(1000, data.count())

    # TODO test additional_options


if __name__ == '__main__':
    unittest.main()



import unittest

import easyglue

from pyspark.context import SparkContext
from awsglue.context import GlueContext


class TestCatalogRead(unittest.TestCase):

    glue = GlueContext(SparkContext.getOrCreate())

    def test_validate_qualified_name(self):
        from easyglue.reader._CatalogMixin import _validate_qualified_name
        database, table = _validate_qualified_name("default.legislators")
        self.assertEqual("default", database)
        self.assertEqual("legislators", table)

    def test_validate_qualified_name_error(self):
        from easyglue.reader._CatalogMixin import _validate_qualified_name
        self.assertRaises(ValueError, _validate_qualified_name, "legislators")

    def test_table(self):
        data = self.glue.read().table("sampledata.mockaroo_csv")
        self.assertEqual(1000, data.count())

    def test_catalog(self):
        data = self.glue.read().catalog("sampledata", "mockaroo_csv")
        self.assertEqual(1000, data.count())


if __name__ == '__main__':
    unittest.main()



from pyspark.context import SparkContext
from awsglue.context import GlueContext

import easyglue


def main():
    # Create a Glue context
    glue = GlueContext(SparkContext.getOrCreate())

    # Create a DynamicFrame using the 'persons_json' table
    persons_dyf = glue.read().json("s3://bertolb/sampledata/mockaroo/json")
    # persons_dyf = glue.read().catalog("legislators", "persons_json")
    # persons_dyf = glueContext.create_dynamic_frame.from_catalog(database="legislators", table_name="persons_json")

    # Print out information about this data
    print("Count:  ", persons_dyf.count())
    persons_dyf.printSchema()


if __name__ == "__main__":
    main()



from easyglue.reader import EasyDynamicFrameReader

from awsglue.context import GlueContext


def read(self):  # Have to add self since this will become a method
    return EasyDynamicFrameReader(glue_context=self)


setattr(GlueContext, 'read', read)



def reader_method(func):
    """
    Decorator method, designed to be used in all methods that read a dataset and return it as a DynamicFrame. The
    decorator will call the wrapped method, then will clear all the options dictionaries so that options from a read
    don't reappear in the next read.
    :param func: Reader function
    :return: Result of the reader function
    """
    def wrapper(self, *args, **kwargs):
        result = func(self, *args, **kwargs)
        self.connection_options_dict.clear()
        self.format_options_dict.clear()
        self.additional_options_dict.clear()
        return result

    return wrapper



from typing import Any

from awsglue.context import GlueContext
from awsglue.dynamicframe import DynamicFrame

from easyglue.utils import reader_method


class OthersMixin:
    glue_context: GlueContext
    connection_options_dict: dict

    @reader_method
    def dynamodb(self, table_name: str, transformation_ctx: str = "", **kwargs: Any) -> DynamicFrame:
        """
        Reads a DynamoDB dataset by calling create_dynamic_frame_from_options with the right configuration
        :param table_name: Name of the DynamoDB table
        :param transformation_ctx: Glue transformation context
        :param kwargs: Keyword arguments
        :return:DynamicFrame representing the dataset
        """
        self.connection_options_dict['dynamodb.input.tableName'] = table_name

        return self.glue_context.create_dynamic_frame_from_options(connection_type='dynamodb',
                                                                   connection_options=self.connection_options_dict,
                                                                   transformation_ctx=transformation_ctx,
                                                                   kwargs=kwargs
                                                                   )

    @reader_method
    def ddb(self, table_name: str, transformation_ctx: str = "", **kwargs: Any) -> DynamicFrame:
        """
        Reads a DynamoDB dataset by calling create_dynamic_frame_from_options with the right configuration
        :param table_name: Name of the DynamoDB table
        :param transformation_ctx: Glue transformation context
        :param kwargs: Keyword arguments
        :return:DynamicFrame representing the dataset
        """
        return self.dynamodb(table_name, transformation_ctx, kwargs=kwargs)



import unittest

import easyglue

from pyspark.context import SparkContext
from pyspark.sql.types import *
from awsglue.context import GlueContext


class TestRDDRead(unittest.TestCase):

    sc = SparkContext.getOrCreate()
    glue = GlueContext(sc)

    def test_rdd(self):
        data = [["Mark,", 1], ["Anne", 2], ["Carlos", 3], ["Ghada", 4], ["Mikhail", 5]]
        rdd = self.sc.parallelize(data)

        schema_string = "name id"
        fields = [StructField(field_name, StringType(), True) for field_name in schema_string.split()]
        schema = StructType(fields)

        dyf = self.glue.read().rdd(rdd, "test_rdd", schema)
        self.assertEqual(5, dyf.count())


if __name__ == '__main__':
    unittest.main()



from typing import Callable

from awsglue.context import GlueContext

from easyglue.utils import reader_method


class JDBCMixin:
    glue_context: GlueContext
    connection_options_dict: dict
    connection_options: Callable

    @reader_method
    def jdbc(self, dbtable: str, url: str, user: str, password: str,
             redshift_tmp_dir: str = "", custom_jdbc_driver_s3_path: str = "", custom_jdbc_driver_class_name: str = "",
             database_type: str = "", transformation_ctx: str = "", push_down_predicate: str = ""):
        """
        Reads a dataset from a JDBC source by calling create_dynamic_frame.from_options with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param dbtable: Name of the JDBC database
        :param url: JDBC URL to connect to
        :param user: Username to authenticate with when connecting to the JDBC database
        :param password: Password to authenticate with when connecting to the JDBC database
        :param redshift_tmp_dir: Temporary path to be used when reading/writing from/to Redshift
        :param custom_jdbc_driver_s3_path: Path to the S3 object containing the custom JDBC driver to be used
        :param custom_jdbc_driver_class_name: Class name to be used when using a custom driver
        :param database_type: JDBC database type
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: Push down predicate to be applied
        :return: DynamicFrame representing the JDBC table
        """

        self.connection_options({
            'url': url,
            'dbtable': dbtable,
            'redshiftTmpDir': redshift_tmp_dir,
            'user': user,
            'password': password,
        })

        if custom_jdbc_driver_s3_path and custom_jdbc_driver_class_name:
            self.connection_options({
                'customJdbcDriverS3Path': custom_jdbc_driver_s3_path,
                'customJdbcDriverClassName': custom_jdbc_driver_class_name
            })

        db_type = database_type if database_type else url.split(':')[1]

        return self.glue_context.create_dynamic_frame.from_options(connection_type=db_type,
                                                                   connection_options=self.connection_options_dict,
                                                                   transformation_ctx=transformation_ctx,
                                                                   push_down_predicate=push_down_predicate)



from awsglue.context import GlueContext

from easyglue.reader._CatalogMixin import CatalogMixin
from easyglue.reader._JDBCMixin import JDBCMixin
from easyglue.reader._OthersMixin import OthersMixin
from easyglue.reader._RDDMixin import RDDMixin
from easyglue.reader._S3Mixin import S3Mixin


class EasyDynamicFrameReader(CatalogMixin, JDBCMixin, OthersMixin, RDDMixin, S3Mixin):
    connection_options_dict = {}
    format_options_dict = {}
    additional_options_dict = {}
    data_format = ''

    def __init__(self, glue_context: GlueContext):
        """
        Initializes the EasyDynamicFrameReader with the glueContext provided by the application
        :param glue_context: GlueContext object
        """
        self.glue_context = glue_context

    def format_option(self, key: str, value: str):
        """
        Stores a format option for later use when reading
        :param key: Format option key
        :param value: Format option value
        :return: None
        """
        self.format_options_dict.update({key: value})
        return self

    def format_options(self, options: dict):
        """
        Stores a dictionary of format options for later use when reading
        :param options: Format options dictionary
        :return: None
        """
        self.format_options_dict = options
        return self

    def connection_option(self, key: str, value: str):
        """
        Stores a connection option for later use when reading
        :param key: Connection option key
        :param value: Connection option value
        :return: None
        """
        self.format_options_dict.update({key: value})
        return self

    def connection_options(self, options: dict):
        """
        Stores a dictionary of connection options for later use when reading
        :param options: Connection options dictionary
        :return: None
        """
        self.connection_options_dict = options
        return self

    def additional_option(self, key: str, value: str):
        """
        Stores an additional option for later use when reading
        :param key: Additional option key
        :param value: Additional option value
        :return: None
        """
        self.additional_options_dict.update({key: value})
        return self

    def additional_options(self, options: dict):
        """
        Stores a dictionary of additional options for later use when reading
        :param options: Additional options dictionary
        :return: None
        """
        self.additional_options_dict = options
        return self

    def option(self, key: str, value: str):
        """
        Method added to comply with Spark's DataframeReader 'option' method. Routes the option as a connection option
        :param key: Connection option key
        :param value: Connection option value
        :return: None
        """
        return self.connection_option(key, value)

    def options(self, options: dict):
        """
        Method added to comply with Spark's DataframeReader 'options' method. Routes the options as connection options
        :param options: Connection options dictionary
        :return: None
        """
        return self.connection_options(options)



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="easyglue",
    version="0.0.7",
    author="Albert Quiroga",
    author_email="albertquirogabertolin@gmail.com",
    description="Glue DynamicFrame syntax closer to DataFrames",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    python_requires=">=3.0"
)



from awsglue.context import GlueContext
from awsglue.dynamicframe import DynamicFrame

from easyglue.utils import reader_method


class RDDMixin:
    glue_context: GlueContext

    @reader_method
    def rdd(self, source_rdd, name: str, schema=None, sample_ratio=None) -> DynamicFrame:
        """
        Reads a dataset from an RDD object
        :param self: Self reference to the EasyDynamicFrameReader class
        :param source_rdd: RDD object to read from
        :param name: Name to be given to the resulting DynamicFrame
        :param schema: (Optional) Schema to be applied to the resulting DynamicFrame
        :param sample_ratio: (Optional) Sampling ratio to apply when reading from the RDD
        :return: DynamicFrame object representing the RDD
        """
        return self.glue_context.create_dynamic_frame_from_rdd(data=source_rdd,
                                                               name=name,
                                                               schema=schema,
                                                               sample_ratio=sample_ratio)



import unittest

import easyglue

from pyspark.context import SparkContext
from awsglue.context import GlueContext


class TestS3Read(unittest.TestCase):

    glue = GlueContext(SparkContext.getOrCreate())

    def test_process_s3_path(self):
        from easyglue.reader._S3Mixin import _process_s3_path
        result = _process_s3_path('s3://test')
        self.assertTrue(isinstance(result, list))

    def test_process_s3_path_incorrect(self):
        from easyglue.reader._S3Mixin import _process_s3_path
        self.assertRaises(TypeError, _process_s3_path, 1)

    def test_process_s3_path_empty(self):
        from easyglue.reader._S3Mixin import _process_s3_path
        self.assertRaises(ValueError, _process_s3_path, '')

    def test_csv(self):
        data = self.glue.read().csv("s3://bertolb/sampledata/mockaroo/csv/")
        self.assertEqual(1001, data.count())  # 1001 because of the header

    def test_json(self):
        data = self.glue.read().json("s3://bertolb/sampledata/mockaroo/json/")
        self.assertEqual(1000, data.count())

    def test_avro(self):
        data = self.glue.read().avro("s3://bertolb/sampledata/mockaroo/avro/")
        self.assertEqual(1000, data.count())

    def test_ion(self):
        data = self.glue.read().ion("s3://bertolb/sampledata/mockaroo/json/")  # Testing with JSON for now
        self.assertEqual(1000, data.count())

    # TODO test groklog

    def test_orc(self):
        data = self.glue.read().orc("s3://bertolb/sampledata/mockaroo/orc/")
        self.assertEqual(1000, data.count())

    def test_parquet(self):
        data = self.glue.read().parquet("s3://bertolb/sampledata/mockaroo/parquet/")
        self.assertEqual(1000, data.count())

    def test_glueparquet(self):
        data = self.glue.read().glueparquet("s3://bertolb/sampledata/mockaroo/glueparquet/")
        self.assertEqual(1000, data.count())

    def test_xml(self):
        data = self.glue.read().format_option("rowTag", "row").xml("s3://bertolb/sampledata/mockaroo/xml/")
        self.assertEqual(1000, data.count())


if __name__ == '__main__':
    unittest.main()



from typing import Any, Union

from awsglue.context import GlueContext
from awsglue.dynamicframe import DynamicFrame

from easyglue.utils import reader_method


def _process_s3_path(s3_paths) -> list:
    """
    Handles the fact that s3 path can be a single string or an array of strings, also does parameter validation
    :param s3_paths: String or list of strings containing the s3 location(s) to read from
    :return: List of strings
    """
    if s3_paths:
        if isinstance(s3_paths, str):
            return [s3_paths]
        elif isinstance(s3_paths, list):
            return s3_paths
        else:
            raise TypeError(
                f'Attribute "s3_paths" must be either str or list, {type(s3_paths)} was provided instead')
    else:
        raise ValueError(f'Attribute "s3_paths" is empty')


class S3Mixin:
    glue_context: GlueContext
    connection_options_dict: dict
    format_options_dict: dict
    additional_options_dict: dict
    data_format: str

    @reader_method
    def _read_from_s3(self, data_format: str, s3_paths: Union[str, list] = "", transformation_ctx: str = "",
                      push_down_predicate: str = "", **kwargs: Any) -> DynamicFrame:
        """
        Reads a dataset from S3 by calling create_dynamic_frame.from_options with the right configuration
        :param data_format: Format of the underlying dataset
        :param s3_paths: S3 paths to be read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        self.connection_options_dict['paths'] = _process_s3_path(s3_paths)

        return self.glue_context.create_dynamic_frame_from_options(connection_type='s3',
                                                                   connection_options=self.connection_options_dict,
                                                                   format=data_format,
                                                                   format_options=self.format_options_dict,
                                                                   transformation_ctx=transformation_ctx,
                                                                   push_down_predicate=push_down_predicate,
                                                                   kwargs=kwargs
                                                                   )

    def csv(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
            **kwargs: Any) -> DynamicFrame:
        """
        Reads a CSV dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='csv', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def json(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
             **kwargs: Any) -> DynamicFrame:
        """
        Reads a JSON dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='json', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def avro(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
             **kwargs: Any) -> DynamicFrame:
        """
        Reads an Avro dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='avro', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def ion(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
            **kwargs: Any) -> DynamicFrame:
        """
        Reads an Ion dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='ion', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def groklog(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
                **kwargs: Any) -> DynamicFrame:
        """
        Reads a Grok-parsable dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='grokLog', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def orc(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
            **kwargs: Any) -> DynamicFrame:
        """
        Reads an ORC dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='orc', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def parquet(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
                **kwargs: Any) -> DynamicFrame:
        """
        Reads a Parquet dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='parquet', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def glueparquet(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
                    **kwargs: Any) -> DynamicFrame:
        """
        Reads a GlueParquet dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='parquet', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)

    def xml(self, s3_paths, transformation_ctx: str = "", push_down_predicate: str = "",
            **kwargs: Any) -> DynamicFrame:
        """
        Reads an XML dataset by calling the _read_from_s3 method with the right configuration
        :param self: Self reference to the EasyDynamicFrameReader class
        :param s3_paths: Paths to read from
        :param transformation_ctx: Glue transformation context
        :param push_down_predicate: S3 push down predicate to be applied
        :param kwargs: Keyword arguments
        :return: DynamicFrame representing the dataset
        """
        return self._read_from_s3(data_format='xml', s3_paths=s3_paths, transformation_ctx=transformation_ctx,
                                  push_down_predicate=push_down_predicate, kwargs=kwargs)
